==> deepin-repair-tools_1.0.9.orig.tar.xz: deepin-repair-tools-1.0.9/translations/deepin-repair-tools_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>Réparation des paquets DPKG</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Afficher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Cacher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Impossible de mettre à niveau ou d&apos;installer l&apos;application</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Réparation, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Échec de la réparation</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair succeeded</source>
        <translation>Réparation réussie</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Nettoyer le disque</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Partition système</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Nettoyer</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="152"/>
        <source>%1 (on %2)</source>
        <translation>%1 (sur %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="191"/>
        <source>Cleaning %1</source>
        <translation>Nettoyage de %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="237"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 a été nettoyé</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Réparer le menu de démarrage</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Afficher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Cacher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Impossible de trouver le menu de démarrage pour accéder au système</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Réparation, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair succeeded</source>
        <translation>Réparation réussie</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Échec de la réparation</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Réinitialiser le mot de passe</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Réinitialiser le mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Confirmer le mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Veuillez saisir un nouveau mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>The two passwords don&apos;t match</source>
        <translation>Les deux mots de passe ne correspondent pas</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="128"/>
        <source>Reset password successfully</source>
        <translation>Réinitialisation du mot de passe réussie</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="154"/>
        <source>Forgot login password</source>
        <translation>Mot de passe oublié</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="142"/>
        <source>%1 (on %2)</source>
        <translation>%1 (sur %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>Réparation de privilège</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>Impossible d&apos;accéder au bureau en raison d&apos;une erreur de privilège</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="72"/>
        <source>Repairing, please wait...</source>
        <translation>Réparation, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="91"/>
        <source>Reset privilege successfully</source>
        <translation>Réinitialisation des privilèges terminée avec succès</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="94"/>
        <source>Reset privilege failed</source>
        <translation>Échec de réinitialisation des privilèges</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Vérification de l&apos;état du disque dur, veuillez patienter...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="36"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="40"/>
        <source>Restart Now</source>
        <translation>Redémarrer maintenant</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="139"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Erreur de partition de disque dur %1, veuillez réparer</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="151"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Veuillez redémarrer votre ordinateur pour terminer la réparation</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="177"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Réparation du disque dur, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="140"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>La réparation peut causer la perte de données, veuillez confirmer et continuer</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="38"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>Repair succeeded</source>
        <translation>Réparation réussie</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="156"/>
        <source>Repair failed</source>
        <translation>Échec de la réparation</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Repair</source>
        <translation>Deepin Repair</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="46"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Deepin Repair est un outil pour aider les utilisateurs à résoudre rapidement certains problèmes dans deepin, y compris la détection de disque dur, nettoyage de disque, réparation DPKG, réparation de démarrage, réparation de privilèges, réinitialisation de mot de passe, etc.</translation>
    </message>
</context>
</TS>

==> deepin-repair-tools_1.0.14.orig.tar.xz: deepin-repair-tools-1.0.14/translations/deepin-repair-tools_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>Réparation des paquets DPKG</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Afficher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Cacher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Impossible de mettre à niveau ou d&apos;installer l&apos;application</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Réparation en cours, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Échec de la réparation</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair successful</source>
        <translation>Réparation réussie</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Nettoyer le disque</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Partition système</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Nettoyer</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="153"/>
        <source>%1 (on %2)</source>
        <translation>%1 (sur %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="192"/>
        <source>Cleaning %1</source>
        <translation>Nettoyage de %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="238"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 a été nettoyé</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Réparer le menu de démarrage</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Afficher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Cacher les détails</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Impossible de trouver le menu de démarrage pour accéder au système</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Réparation en cours, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair successful</source>
        <translation>Réparation réussie</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Échec de la réparation</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Réinitialiser le mot de passe</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Réinitialiser le mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Confirmer le mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Veuillez saisir un nouveau mot de passe</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>Passwords do not match</source>
        <translation>Les mots de passe ne correspondent pas</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="130"/>
        <source>Reset password successfully</source>
        <translation>Réinitialisation du mot de passe réussie</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="156"/>
        <source>Forgot login password</source>
        <translation>Mot de passe oublié</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="144"/>
        <source>%1 (on %2)</source>
        <translation>%1 (sur %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>Réparation de privilège</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>Impossible d&apos;accéder au bureau en raison d&apos;une erreur de privilège</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="71"/>
        <source>Repairing, please wait...</source>
        <translation>Réparation, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="90"/>
        <source>Reset privilege successfully</source>
        <translation>Réinitialisation des privilèges réussie</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="93"/>
        <source>Reset failed</source>
        <translation>Échec de la réinitialisation</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Vérification de l&apos;état du disque dur, veuillez patienter...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="37"/>
        <source>Repair</source>
        <translation>Réparer</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="41"/>
        <source>Restart Now</source>
        <translation>Redémarrer maintenant</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="149"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Erreur de partition de disque dur %1, veuillez réparer</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="160"/>
        <source>Repair successful</source>
        <translation>Réparation réussie</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="161"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Veuillez redémarrer votre ordinateur pour terminer la réparation</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="187"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Réparation du disque dur, veuillez patienter…</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>La réparation peut causer la perte de données, veuillez confirmer et continuer</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="39"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="166"/>
        <source>Repair failed</source>
        <translation>Échec de la réparation</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="47"/>
        <source>Deepin Repair</source>
        <translation>Deepin Repair</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="48"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Deepin Repair est un outil pour aider les utilisateurs à résoudre rapidement certains problèmes dans deepin, y compris la détection de disque dur, nettoyage de disque, réparation DPKG, réparation de démarrage, réparation de privilèges, réinitialisation de mot de passe, etc.</translation>
    </message>
</context>
</TS>
